@@ -1,7 +1,7 @@
 package App::PMUtils;
 
-our $DATE = '2016-10-11'; # DATE
-our $VERSION = '0.62'; # VERSION
+our $DATE = '2016-11-07'; # DATE
+our $VERSION = '0.63'; # VERSION
 
 use 5.010001;
 
@@ -165,7 +165,7 @@ sub rel2mod {
     my @res;
     for (@{ $args{releases} }) {
         s!.+/!!; # remove directory path
-        s/-v?\d.+//;
+        s/(.+)-v?\d.+/$1/;
         s/-/::/g;
         push @res, $_;
     }
@@ -188,7 +188,7 @@ App::PMUtils - Command-line utilities related to Perl modules
 
 =head1 VERSION
 
-This document describes version 0.62 of App::PMUtils (from Perl distribution App-PMUtils), released on 2016-10-11.
+This document describes version 0.63 of App::PMUtils (from Perl distribution App-PMUtils), released on 2016-11-07.
 
 =head1 SYNOPSIS
 
@@ -385,7 +385,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-PMUtil
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-PMUtils>.
+Source repository is at L<https://github.com/sharyanto/perl-App-PMUtils>.
 
 =head1 BUGS
 
